@@ -5,7 +5,7 @@ import logging
 import math
 from datetime import datetime
 from .parameter import Parameter
-from .tools import handle_date, handle_db_to_list, handle_db_dict, handle_db_id
+from .tools import handle_date, handle_db_to_list, handle_db_dict, handle_db_id, handle_db_remove
 from flask import abort, Response
 from bson import ObjectId
 
@@ -51,6 +51,8 @@ class DBConnect():
     def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
         try:
             find_docu = handle_db_id(find_docu)
+            # 排除假删除数据
+            find_docu = handle_db_remove(find_docu)
             if many:
                 student = self.mongo_collection.update_many(
                     find_docu, modify_docu)
@@ -64,9 +66,39 @@ class DBConnect():
             logging.warning(str_data)
             abort(Response(str_data, 500, {}))
 
+    def delete_docu(self, find_docu: dict, many: bool = False, false_delete: bool = False) -> list:
+        try:
+            if false_delete:
+                # 假删除流程
+                modify_dict = {'$set': {'remove_time': datetime.today()}}
+                result = self.update_docu(
+                    find_docu=find_docu, modify_docu=modify_dict, many=many)
+                if not result['modified_count']:
+                    logging.error('MongoDB(组件)出现删除异常: 没有任何文档被假删除')
+                return {'deleted_count': result['modified_count'], 'false_delete': false_delete}
+            else:
+                find_docu = handle_db_id(find_docu)
+                find_docu = handle_db_remove(find_docu)
+                # 真删除流程
+                if many:
+                    # 文档批量删除方式
+                    result = self.mongo_collection.delete_many(find_docu)
+                else:
+                    # 文档精确删除方式
+                    result = self.mongo_collection.delete_one(find_docu)
+                if not result.deleted_count:
+                    logging.error('MongoDB(组件)出现删除异常: 没有任何文档被真删除')
+                # 返回删除成功条数
+                return {'deleted_count': result.deleted_count, 'false_delete': false_delete}
+        except Exception as err:
+            str_data = 'MongoDB(组件)出现删除错误: {0}'.format(err)
+            logging.warning(str_data)
+            abort(Response(str_data, 500, {}))
+
     def find_docu(self, find_dict: dict, many: bool = True) -> list:
         try:
             find_dict = handle_db_id(find_dict)
+            find_dict = handle_db_remove(find_dict)
             if many:
                 # 多文档查询方式
                 query_cursor = self.mongo_collection.find(find_dict)
@@ -92,20 +124,14 @@ class DBConnect():
         if not isinstance(id, str):
             logging.warning("类型错误，预期 %s ,却得到 %s" % (list, type(id)))
             abort(Response("类型错误，预期 %s ,却得到 %s" % (list, type(id)), 400, {}))
-        try:
-            objId = ObjectId(id)
-        except:
-            logging.warning('id不合法，转换失败 id= %s' % (id,))
-            abort(Response('id不合法，转换失败 id= %s' % (id,), 400, {}))
-        entity = self.mongo_collection.find_one({'_id': objId})
-        if entity is None:
+        entity = self.find_docu({'id': id}, many=False)
+        if entity is None or len(entity) == 0:
             if raise_err:
-                logging.info('找不到 id= %s 的记录' % (id,))
+                logging.warning('找不到 id= %s 的记录' % (id,))
                 abort(Response('找不到 id= %s 的记录' % (id,), 400, {}))
             else:
                 return None
-        entity['_id'] = str(entity['_id'])
-        return dict(entity)
+        return entity[0]
 
     def find_docu_by_id_list(self, id_list: list) -> list:
         """
@@ -121,8 +147,8 @@ class DBConnect():
         for id in id_list:
             id_search.append({'_id': ObjectId(id)})
         find_dict = {'$or': id_search}
-        data = self.mongo_collection.find(find_dict)
-        return handle_db_to_list(data)
+        data = self.find_docu(find_dict)
+        return data
 
     def find_paging(self, parameter: Parameter) -> dict:
         parameter.verification(
@@ -154,14 +180,19 @@ class DBConnect():
             str_data = '计算组件分页参数异常: {0}'.format(err)
             logging.warning(str_data)
             abort(Response(str_data, 400, {}))
-        # 查找字典和排序列表
-        find_dict = {}
+        # 查找假删除数据的数据量
+        remove_count = self.mongo_collection.find(
+            {'remove_time': {'$exists': True}}).count()
+        # 查找字典和排序列表，处理假删除数据
+        find_dict = handle_db_remove({})
         sort_list = []
         if len(columns):
             for i in range(len(columns)):
                 # 整理请求参数中的筛选项字典
                 if type(filtered_value[i]) == int:
                     find_dict[columns[i]] = filtered_value[i]
+                elif columns[i] == 'id' or columns[i] == '_id':
+                    find_dict['_id'] = ObjectId(str(filtered_value[i]))
                 else:
                     if filtered_value[i].strip() != '':
                         find_dict[columns[i]] = {'$regex': filtered_value[i]}
@@ -185,10 +216,11 @@ class DBConnect():
         records_filtered = find_data.count()
         if not records_filtered:
             return {
-                'records_total': self.mongo_collection.estimated_document_count(),
+                'records_total': self.mongo_collection.estimated_document_count()-remove_count,
                 'records_filtered': 0,
                 'query_result': [],
                 'total_pages': 0,
+                'remove_count': remove_count,
             }
         if sort_list:
             find_data.sort(sort_list).limit(
@@ -198,8 +230,9 @@ class DBConnect():
         # 处理返回数据
         query_result = handle_db_to_list(find_data)
         return {
-            'records_total': self.mongo_collection.estimated_document_count(),
+            'records_total': self.mongo_collection.estimated_document_count()-remove_count,
             'records_filtered': records_filtered,
             'query_result': query_result,
             'total_pages': math.ceil(records_filtered / page_size),
+            'remove_count': remove_count,
         }
