@@ -20,8 +20,8 @@ def handle_date(date: str, date_type='start') -> datetime:
             date_data = datetime.fromtimestamp(int(date_time))
         else:
             date_data = datetime.strptime(date, "%Y-%m-%d")
-        if date_type == 'end' and date_data:
-            date_data += timedelta(hours=23, minutes=59, seconds=59)
+            if date_type == 'end' and date_data:
+                date_data += timedelta(hours=23, minutes=59, seconds=59)
     except Exception as err:
         str_data = '日期字符串解析异常: {0}'.format(err)
         logging.warning(str_data)
@@ -69,3 +69,14 @@ def handle_db_id(data_dict: dict) -> dict:
         str_data = 'MongoDB _id 格式解析异常: {0}'.format(err)
         logging.warning(str_data)
         abort(Response(str_data, 400, {}))
+
+
+def handle_db_remove(find_dict: dict) -> dict:
+    try:
+        if not find_dict.__contains__('remove_time'):
+            find_dict['remove_time'] = {'$exists': False}
+        return find_dict
+    except Exception as err:
+        str_data = 'MongoDB 移除数据处理异常: {0}'.format(err)
+        logging.warning(str_data)
+        abort(Response(str_data, 500, {}))
